# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

#TODO: BR:/R: perl(IP::Authority) when available

Summary:	Perl extension for manipulating IPv4/IPv6 addresses
Name:		perl-Net-IP
Version:	1.26
Release:	30.%{__distinit}%{__distvers}
License:	HPND AND (GPL-1.0-or-later OR Artistic-1.0-Perl)
URL:		https://metacpan.org/release/Net-IP
Source:		https://cpan.metacpan.org/modules/by-module/Net/Net-IP-%{version}.tar.gz
Patch0:		Net-IP-1.26-rt60439.patch
Patch1:		Net-IP-1.26-shellbang.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Math::BigInt)
BuildRequires:	perl(overload)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
# Script Runtime
BuildRequires:	perl(Getopt::Std)
# Test Suite
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(FileHandle)
BuildRequires:	perl(lib)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
This is the Net::IP module, designed to allow easy manipulation of IPv4 and
IPv6 addresses.

There is also a small application that uses the IP.pm module: ipcount.pl.
Basically, it's an IP address mini-calculator; it can calculate the number of
IP addresses in a prefix or all the prefixes contained in a given range.

%prep
%setup -q -n Net-IP-%{version}

# Apply fix for zero networks (#197425, CPAN RT#20265, CPAN RT#60439)
%patch -P 0

# Fix shellbangs in shipped scripts
%patch -P 1

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

# This should work for 0.0.0.0
# https://bugzilla.redhat.com/show_bug.cgi?id=197425
PERL5LIB=%{buildroot}%{perl_vendorlib} ./iptab

%files
%license COPYING
%doc Changes README
# GPL-1.0-or-later OR Artistic-1.0-Perl
%{_bindir}/ipcount
%{_bindir}/iptab
# HPND
%{perl_vendorlib}/Net/
%{_mandir}/man3/Net::IP.3*

%changelog
* Fri May  5 2023 Paul Howarth <paul@city-fan.org> - 1.26-30
- Use SPDX-format license tag
- Switch upstream from search.cpan,org to metacpan.org
- Avoid use of deprecated patch syntax
- Use %%license unconditionally
- Package README file

* Wed Apr 25 2018 Paul Howarth <paul@city-fan.org> - 1.26-14
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Tue Sep 13 2016 Paul Howarth <paul@city-fan.org> - 1.26-10
- Classify buildreqs by usage
- Apply fix for zero networks (#197425, CPAN RT#20265, CPAN RT#60439)
- Fix shellbangs in shipped scripts
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible
- Simplify find command using -delete

* Thu Nov 29 2012 Paul Howarth <paul@city-fan.org> - 1.26-1
- Update to 1.26
  - This version is authored by Ulrich Wisser
  - CPAN RT#81138: ip types
  - CPAN RT#80164: hexip does not change when ip changes (fix: hexformat needs
    to be cleared by set)
  - CPAN RT#74898: double compression
  - CPAN RT#73232: invalid ipv6 1:2:3:4:5:6:7
  - CPAN RT#73105: invalid ip 1:2
  - CPAN RT#73104: expand 1::2::3
  - CPAN RT#71042: ip_reverse 2001:4f8:3:36:0:0:0:235
  - CPAN RT#45165: ip_range_to_prefix updated documentation
  - CPAN RT#32232: accepts 61-217-102-8.hinet-ip.hinet.net as range

* Fri Jun  8 2012 Paul Howarth <paul@city-fan.org> - 1.25-19
- BR: perl(Exporter) and perl(Math::BigInt)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Tue Jul  5 2011 Paul Howarth <paul@city-fan.org> - 1.25-17
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 1.25-8
- Rebuild for perl 5.12.1 in Rawhide

* Fri May  7 2010 Paul Howarth <paul@city-fan.org> - 1.25-7
- Fix dist tag to work with RHEL6 Beta

* Wed Feb 17 2010 Paul Howarth <paul@city-fan.org> - 1.25-6
- Dist tag for Rawhide no longer needs special-casing

* Fri Aug 28 2009 Paul Howarth <paul@city-fan.org> - 1.25-5
- Define RPM macros in global scope

* Fri Oct 31 2008 Paul Howarth <paul@city-fan.org> - 1.25-4
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)
- Tweak dist tag macros to work on current Rawhide with three-part releasenum

* Mon Mar 19 2007 Paul Howarth <paul@city-fan.org> - 1.25-3
- Fix dist tag for development builds and Fedora 7 onwards
- Fix argument order for find with -depth
- BuildRequire perl(ExtUtils::MakeMaker)

* Fri May 26 2006 Paul Howarth <paul@city-fan.org> - 1.25-2
- Fix broken dependency due to removal of %%__perl_version macro definition

* Thu May 25 2006 Paul Howarth <paul@city-fan.org> - 1.25-1
- Update to 1.25
- Simplify distribution-detection
- Define %%{__id_u} in a more portable way

* Wed Oct 19 2005 Paul Howarth <paul@city-fan.org> - 1.24-1
- Update to 1.24
- Fix directory ownership
- Don't use macros in build-time command pathnames, hardcode them instead
- Don't use %%{__perl_package} macro
- Use search.cpan.org URLs
- Unconditionally remove buildroot in %%clean and %%install

* Fri Sep  2 2005 Paul Howarth <paul@city-fan.org> - 1.23-2
- Add note about package being available in Fedora Extras
- Remove redundant find of empty .bs files

* Fri Jun 24 2005 Paul Howarth <paul@city-fan.org> - 1.23-1
- Initial build
